==> vtours-ttxmlwebservice-1.8.3-911aaa.zip: src/Vtours/TTXmlWebService/Model/Response/v2/PackageOffersRS.php <==
<?php

namespace Vtours\TTXmlWebService\Model\Response\V2;

/**
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 *  Any unauthorized use of this software without a valid license is a violation of the license agreement
 *  and will be prosecuted by civil and criminal law.
 *
 *   @copyright 2017 Lifestyle Webconsulting GmbH
 */

use JMS\Serializer\Annotation as Serializer;
use JMS\Serializer\Metadata;
use Vtours\TTXmlWebService\Model\Response\V2\RSMetaData;
use Vtours\TTXmlWebService\Model\Response\V2\GeoDictionary;
use Vtours\TTXmlWebService\Model\Response\V2\HotelDictionary;
use Vtours\TTXmlWebService\Model\Response\V2\StationDictionary;
use Vtours\TTXmlWebService\Model\Response\V2\Offers;

/**
 * @Serializer\AccessType(type=Metadata\PropertyMetadata::ACCESS_TYPE_PUBLIC_METHOD)
 * @Serializer\ExclusionPolicy(Serializer\ExclusionPolicy::ALL)
 */
class PackageOffersRS
{

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\V2\PackageOffersRS")
     * @Serializer\SerializedName("PackageOffersRS")
     *
     * @var PackageOffersRS
     */
    private $PackageOffersRS;

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\V2\RSMetaData")
     * @Serializer\SerializedName("RS_Metadata")
     *
     * @var RSMetaData
     */
    private $RSMetadata;

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\V2\GeoDictionary")
     * @Serializer\SerializedName("GeoDictionary")
     *
     * @var GeoDictionary
     */
    private $geoDictionary;

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\V2\HotelDictionary")
     * @Serializer\SerializedName("HotelDictionary")
     *
     * @var HotelDictionary
     */
    private $hotelDictionary;

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\V2\StationDictionary")
     * @Serializer\SerializedName("StationDictionary")
     *
     * @var StationDictionary
     */
    private $stationDictionary;

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\V2\Offers")
     * @Serializer\SerializedName("Offers")
     *
     * @var Offers
     */
    private $offers;

    /**
     * @return PackageOffersRS
     */
    public function getPackageOffersRS()
    {
        return $this->PackageOffersRS;
    }

    /**
     * @param PackageOffersRS $PackageOffersRS
     */
    public function setPackageOffersRS($PackageOffersRS)
    {
        $this->PackageOffersRS = $PackageOffersRS;
    }

    /**
     * @return RSMetaData
     */
    public function getRSMetaData()
    {
        return $this->RSMetadata;
    }

    /**
     * @param RSMetaData $RSMetaData
     */
    public function setRSMetaData($RSMetaData)
    {
        $this->RSMetadata = $RSMetaData;
    }

    /**
     * @return \Vtours\TTXmlWebService\Model\Response\V2\GeoDictionary
     */
    public function getGeoDictionary()
    {
        return $this->geoDictionary;
    }

    /**
     * @param \Vtours\TTXmlWebService\Model\Response\V2\GeoDictionary $geoDictionary
     */
    public function setGeoDictionary($geoDictionary)
    {
        $this->geoDictionary = $geoDictionary;
    }

    /**
     * @return \Vtours\TTXmlWebService\Model\Response\V2\HotelDictionary
     */
    public function getHotelDictionary()
    {
        return $this->hotelDictionary;
    }

    /**
     * @param \Vtours\TTXmlWebService\Model\Response\V2\HotelDictionary $hotelDictionary
     */
    public function setHotelDictionary($hotelDictionary)
    {
        $this->hotelDictionary = $hotelDictionary;
    }

    /**
     * @return \Vtours\TTXmlWebService\Model\Response\V2\StationDictionary
     */
    public function getStationDictionary()
    {
        return $this->stationDictionary;
    }

    /**
     * @param \Vtours\TTXmlWebService\Model\Response\V2\StationDictionary $stationDictionary
     */
    public function setStationDictionary($stationDictionary)
    {
        $this->stationDictionary = $stationDictionary;
    }

    /**
     * @return \Vtours\TTXmlWebService\Model\Response\V2\Offers
     */
    public function getOffers()
    {
        return $this->offers;
    }

    /**
     * @param \Vtours\TTXmlWebService\Model\Response\V2\Offers $offers
     */
    public function setOffers($offers)
    {
        $this->offers = $offers;
    }
}

==> vtours-ttxmlwebservice-1.9.8-82564a.zip: src/Vtours/TTXmlWebService/Model/Response/v2/PackageOffersRS.php <==
<?php
/**
 * LICENSE: This Software is the property of Lifestyle Webconsulting GmbH (Aschaffenburg, Germany)
 * and is protected by copyright law - it is NOT Freeware.
 *
 *  Any unauthorized use of this software without a valid license is a violation of the license agreement
 *  and will be prosecuted by civil and criminal law.
 *
 * @copyright 2022 Lifestyle Webconsulting GmbH
 */

namespace Vtours\TTXmlWebService\Model\Response\v2;

use JMS\Serializer\Annotation as Serializer;
use JMS\Serializer\Metadata;
use Vtours\TTXmlWebService\Model\Response\v2\RSMetaData;
use Vtours\TTXmlWebService\Model\Response\v2\GeoDictionary;
use Vtours\TTXmlWebService\Model\Response\v2\HotelDictionary;
use Vtours\TTXmlWebService\Model\Response\v2\StationDictionary;
use Vtours\TTXmlWebService\Model\Response\v2\Offers;

/**
 * @Serializer\AccessType(type=Metadata\PropertyMetadata::ACCESS_TYPE_PUBLIC_METHOD)
 * @Serializer\ExclusionPolicy(Serializer\ExclusionPolicy::ALL)
 */
class PackageOffersRS
{

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\v2\PackageOffersRS")
     * @Serializer\SerializedName("PackageOffersRS")
     *
     * @var PackageOffersRS
     */
    private $PackageOffersRS;

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\v2\RSMetaData")
     * @Serializer\SerializedName("RS_Metadata")
     *
     * @var RSMetaData
     */
    private $RSMetadata;

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\v2\GeoDictionary")
     * @Serializer\SerializedName("GeoDictionary")
     *
     * @var GeoDictionary
     */
    private $geoDictionary;

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\v2\HotelDictionary")
     * @Serializer\SerializedName("HotelDictionary")
     *
     * @var HotelDictionary
     */
    private $hotelDictionary;

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\v2\StationDictionary")
     * @Serializer\SerializedName("StationDictionary")
     *
     * @var StationDictionary
     */
    private $stationDictionary;

    /**
     * @Serializer\Expose()
     * @Serializer\Type("Vtours\TTXmlWebService\Model\Response\v2\Offers")
     * @Serializer\SerializedName("Offers")
     *
     * @var Offers
     */
    private $offers;

    /**
     * @return PackageOffersRS
     */
    public function getPackageOffersRS()
    {
        return $this->PackageOffersRS;
    }

    /**
     * @param PackageOffersRS $PackageOffersRS
     */
    public function setPackageOffersRS($PackageOffersRS)
    {
        $this->PackageOffersRS = $PackageOffersRS;
    }

    /**
     * @return RSMetaData
     */
    public function getRSMetaData()
    {
        return $this->RSMetadata;
    }

    /**
     * @param RSMetaData $RSMetaData
     */
    public function setRSMetaData($RSMetaData)
    {
        $this->RSMetadata = $RSMetaData;
    }

    /**
     * @return \Vtours\TTXmlWebService\Model\Response\v2\GeoDictionary
     */
    public function getGeoDictionary()
    {
        return $this->geoDictionary;
    }

    /**
     * @param \Vtours\TTXmlWebService\Model\Response\v2\GeoDictionary $geoDictionary
     */
    public function setGeoDictionary($geoDictionary)
    {
        $this->geoDictionary = $geoDictionary;
    }

    /**
     * @return \Vtours\TTXmlWebService\Model\Response\v2\HotelDictionary
     */
    public function getHotelDictionary()
    {
        return $this->hotelDictionary;
    }

    /**
     * @param \Vtours\TTXmlWebService\Model\Response\v2\HotelDictionary $hotelDictionary
     */
    public function setHotelDictionary($hotelDictionary)
    {
        $this->hotelDictionary = $hotelDictionary;
    }

    /**
     * @return \Vtours\TTXmlWebService\Model\Response\v2\StationDictionary
     */
    public function getStationDictionary()
    {
        return $this->stationDictionary;
    }

    /**
     * @param \Vtours\TTXmlWebService\Model\Response\v2\StationDictionary $stationDictionary
     */
    public function setStationDictionary($stationDictionary)
    {
        $this->stationDictionary = $stationDictionary;
    }

    /**
     * @return \Vtours\TTXmlWebService\Model\Response\v2\Offers
     */
    public function getOffers()
    {
        return $this->offers;
    }

    /**
     * @param \Vtours\TTXmlWebService\Model\Response\v2\Offers $offers
     */
    public function setOffers($offers)
    {
        $this->offers = $offers;
    }
}
